.. currentmodule:: sardana.pool.poolpseudocounter

.. _sardana-pseudocounter-api:

=============================
Pseudo counter API reference
=============================

.. todo:: document pseudo-counter API reference

.. seealso:: 
    
    :ref:`sardana-pseudocounter-overview`
        the pseudo-counter overview 
    
    :class:`~sardana.tango.pool.PseudoCounter.PseudoCounter`
        the pseudo-counter tango device :term:`API`

..    :class:`~sardana.pool.poolpseudocounter.PoolPseudoCounter`
..        the pseudo-counter class :term:`API`
